@@ -505,7 +505,7 @@ class Symbol(QGraphicsPolygonItem):
             for cnx in self.connections():
                 cnx.update_lines()
             if self.hasParent:
-                for cnx in self.parent.connections():
+                for cnx in self.parentItem().connections():
                     cnx.update_lines()
         return super(Symbol, self).itemChange(change, value)
 
@@ -922,6 +922,11 @@ class Comment(Symbol):
         self.prepareGeometryChange()
         polygon = self.computePolygon(rect.width(), rect.height())
         self.setPolygon(polygon)
+        for cnx in self.connections():
+            cnx.update_lines()
+        if self.hasParent:
+            for cnx in self.parent.connections():
+                cnx.update_lines()
 
     def computePolygon(self, width, height):
         polygon = QPolygon(QRect(0, 0, width, height))
@@ -1173,6 +1178,7 @@ class VerticalSymbol(Symbol):
                     if not isinstance(child, Connection) or not isinstance(
                             child.child, HorizontalSymbol):
                         child.setParentItem(self)
+                        child.parent = self
                         if isinstance(child, Symbol):
                             childYDiff = (
                                     child.y() -
@@ -1191,6 +1197,7 @@ class VerticalSymbol(Symbol):
                             isinstance(child.child, Comment)):
                         # Don't change the parent of a comment
                         continue
+                    child.parent = self
                     child.setParentItem(self)
                     # move child position down when inserting
                     if isinstance(child, Symbol):
