@@ -93,8 +93,8 @@ def getStateList(processRoot):
     states = (child for child in processRoot.getChildren()
             if child.type == STATE)
     # 2) keep only the ones containing a STATELIST token (i.e. no ASTERISK)
-    relevant = [child for state in states for child in state.getChildren()
-            if child.type == STATELIST]
+    relevant = (child for state in states for child in state.getChildren()
+            if child.type == STATELIST)
     # 3) extract the state list from each of them
     stateList = [s.toString() for r in relevant for s in r.getChildren()]
     stateList.append('START')
