@@ -37,6 +37,7 @@ typesCompletionList = []
 varCompletionList = []
 procCompletionList = []
 
+
 class Input(HorizontalSymbol):
     ''' SDL INPUT Symbol '''
     allowed_followers = ['Task', 'ProcedureCall', 'Output', 'Decision',
@@ -83,7 +84,7 @@ class Input(HorizontalSymbol):
         polygon = QPolygon()
         polygon << QPoint(0, 0) \
                 << QPoint(width, 0) \
-                << QPoint(width-15, height/2) \
+                << QPoint(width - 15, height / 2) \
                 << QPoint(width, height) \
                 << QPoint(0, height) \
                 << QPoint(0, 0)
@@ -141,9 +142,9 @@ class Output(VerticalSymbol):
         ''' Compute the polygon to fit in width, height '''
         polygon = QPolygon()
         polygon << QPoint(0, 0) \
-                << QPoint(width-15, 0) \
-                << QPoint(width, height/2) \
-                << QPoint(width-15, height) \
+                << QPoint(width - 15, 0) \
+                << QPoint(width, height / 2) \
+                << QPoint(width - 15, height) \
                 << QPoint(0, height) \
                 << QPoint(0, 0)
         return polygon
@@ -176,7 +177,7 @@ class Decision(VerticalSymbol):
         _, coord_y, width, height = ast.coordinates
         polygon = self.computePolygon(width, height)
         # Define the point where all branches of the decision can join again
-        self.connectionPoint = QPoint(width/2, height+30)
+        self.connectionPoint = QPoint(width / 2, height + 30)
         super(Decision, self).__init__(polygon, parent, text=ast.inputString,
                 y=coord_y, hyperlink=ast.hyperlink)
         self.setBrush(QColor(255, 255, 202))
@@ -203,11 +204,11 @@ class Decision(VerticalSymbol):
     def computePolygon(self, width, height):
         ''' Define polygon points to draw the symbol '''
         polygon = QPolygon()
-        polygon << QPoint(width/2, 0) \
-                << QPoint(width, height/2) \
-                << QPoint(width/2, height) \
-                << QPoint(0, height/2) \
-                << QPoint(width/2, 0)
+        polygon << QPoint(width / 2, 0) \
+                << QPoint(width, height / 2) \
+                << QPoint(width / 2, height) \
+                << QPoint(0, height / 2) \
+                << QPoint(width / 2, 0)
         return polygon
 
     def resizeItem(self, rect):
@@ -224,7 +225,7 @@ class Decision(VerticalSymbol):
         answers = filter(lambda c:
                 isinstance(c, DecisionAnswer), self.childSymbols())
         newY = 0
-        newX = self.boundingRect().width()/2
+        newX = self.boundingRect().width() / 2
         if answers:
             for branch in answers:
                 lastCnx = []
@@ -355,7 +356,7 @@ class DecisionAnswer(HorizontalSymbol):
         ''' Draw ANSWER shape within a polygon boundaries '''
         rect = self.boundingRect()
         left = QRect(rect.x(), rect.y(), 35, rect.height())
-        right = QRect(rect.width()-35, rect.y(), 35, rect.height())
+        right = QRect(rect.width() - 35, rect.y(), 35, rect.height())
         painter.drawArc(left, 2000, 1760)
         painter.drawArc(right, -880, 1760)
         HorizontalSymbol.paint(self, painter, _, __)
@@ -457,18 +458,18 @@ class Label(VerticalSymbol):
         ''' Draw the LABEL symbol within its boundaries '''
         rect = self.boundingRect()
         painter.setPen(Qt.blue)
-        painter.drawEllipse(0, rect.height()/2,
-                rect.width()/4, rect.height()/2)
-        painter.drawLine(rect.width()/4, rect.height()*3/4,
-                rect.width()/2, rect.height()*3/4)
+        painter.drawEllipse(0, rect.height() / 2,
+                rect.width() / 4, rect.height() / 2)
+        painter.drawLine(rect.width() / 4, rect.height() * 3 / 4,
+                rect.width() / 2, rect.height() * 3 / 4)
         # Add arrow head
-        painter.drawLine(rect.width()/2-5, rect.height()*3/4-5,
-                rect.width()/2, rect.height()*3/4)
-        painter.drawLine(rect.width()/2-5, rect.height()*3/4+5,
-                rect.width()/2, rect.height()*3/4)
+        painter.drawLine(rect.width() / 2 - 5, rect.height() * 3 / 4 - 5,
+                rect.width() / 2, rect.height() * 3 / 4)
+        painter.drawLine(rect.width() / 2 - 5, rect.height() * 3 / 4 + 5,
+                rect.width() / 2, rect.height() * 3 / 4)
         # Add vertical line in the middle of the symbol
-        painter.drawLine(rect.width()/2, 0,
-                rect.width()/2, rect.height())
+        painter.drawLine(rect.width() / 2, 0,
+                rect.width() / 2, rect.height())
         super(Label, self).paint(painter, _, __)
 
     def __repr__(self):
@@ -511,13 +512,13 @@ class Condition(VerticalSymbol):
         #font.setPixelSize(40)
         #painter.setFont(font)
         rect = self.boundingRect()
-        painter.drawLines([QPoint(10, 0), QPoint(0, rect.height()/2),
-                           QPoint(0, rect.height()/2),
+        painter.drawLines([QPoint(10, 0), QPoint(0, rect.height() / 2),
+                           QPoint(0, rect.height() / 2),
                            QPoint(10, rect.height())])
-        painter.drawLines([QPoint(rect.width()-10, 0),
-                           QPoint(rect.width(), rect.height()/2),
-                           QPoint(rect.width(), rect.height()/2),
-                           QPoint(rect.width()-10, rect.height())])
+        painter.drawLines([QPoint(rect.width() - 10, 0),
+                           QPoint(rect.width(), rect.height() / 2),
+                           QPoint(rect.width(), rect.height() / 2),
+                           QPoint(rect.width() - 10, rect.height())])
         super(Condition, self).paint(self, painter, _, __)
 
     def __repr__(self):
@@ -615,12 +616,12 @@ class ProcedureCall(VerticalSymbol):
                 << QPoint(width, height) \
                 << QPoint(0, height) \
                 << QPoint(0, 0) \
-                << QPoint(width-7, 0) \
-                << QPoint(width-7, height) \
+                << QPoint(width - 7, 0) \
+                << QPoint(width - 7, height) \
                 << QPoint(7, height) \
                 << QPoint(7, 0)
         return polygon
-    
+
     def completionList(self):
         ''' Return the list of defined procedures for the autocompletion '''
         return procCompletionList
@@ -667,13 +668,13 @@ class TextSymbol(HorizontalSymbol):
     def computePolygon(self, width, height):
         ''' Define the polygon of the text symbol '''
         polygon = QPolygon()
-        polygon << QPoint(width-10, 0) \
+        polygon << QPoint(width - 10, 0) \
                 << QPoint(0, 0) \
                 << QPoint(0, height) \
                 << QPoint(width, height) \
                 << QPoint(width, 10) \
-                << QPoint(width-10, 10) \
-                << QPoint(width-10, 0) \
+                << QPoint(width - 10, 10) \
+                << QPoint(width - 10, 0) \
                 << QPoint(width, 10)
         return polygon
 
@@ -770,7 +771,8 @@ class State(VerticalSymbol):
         comment = ';'
         if self.comment:
             comment = repr(self.comment)
-        if self.hasParent and not self.childSymbols():
+        if self.hasParent and not [s for s in self.childSymbols() if
+                                   not isinstance(s, Comment)]:
             # Do not generate a new STATE when there is no need
             # FIXME: check if childSymbol is a commment
             return ''
